@@ -78,7 +78,7 @@ class Estimator(AbstractEstimator):
         y = y.astype("float64").reshape(-1, 1)
         reg = KernelRidge()
         parameters = {
-            "alpha": stats.reciprocal(a=1e-7, b=1e2, size=10),
+            "alpha": stats.loguniform(a=1e-7, b=1e2),
             "gamma": stats.expon(scale=0.1),
             "kernel": ["rbf"],
         }
