@@ -8,7 +8,6 @@ from dovado_rtl.frame_handling import (
     XdcFrameHandler,
 )
 from dovado_rtl.enums import RTL, RegressionModel
-from dovado_rtl.src_parsing import SourceParser
 from dovado_rtl.point_evaluation import DesignPointEvaluator
 from dovado_rtl.estimation import Estimator
 from dovado_rtl.fitness import FitnessEvaluator
@@ -16,14 +15,15 @@ from dovado_rtl.genetic_algorithm import optimize
 
 
 def main():
-
     vivado.start()
     config = Configuration()
     Path(str(config.get_config("WORK_DIR"))).mkdir(parents=True, exist_ok=True)
 
     src_folder = user_input.ask_code_dir()
-    top_module, top_src = user_input.ask_top_module(src_folder, config)
-    parsed_source = SourceParser(top_src, top_module)
+    top_module, _, parsed_source = user_input.ask_top_module(
+        src_folder, config
+    )
+    parsed_source.set_entity(top_module.get_name())
     synthesis_part = user_input.ask_part()
 
     stop_step = user_input.ask_stop_step()
@@ -55,6 +55,7 @@ def main():
     tcl_handler = TclFrameHandler(
         config,
         parsed_source,
+        src_folder,
         synthesis_part,
         synthesis_directive,
         incremental_mode,
@@ -79,7 +80,7 @@ def main():
         else str(config.get_config("WORK_DIR"))
         + str(config.get_config("VERILOG_BOX")),
         parsed_source.get_hdl(),
-        parsed_source.get_top_level()
+        parsed_source.get_folder()
         if parsed_source.get_hdl() is RTL.VHDL
         else None,
     )
